# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import sys
from .vars import _ExportableConfig

sys.modules[__name__].__class__ = _ExportableConfig



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['GatewayFQDNArgs', 'GatewayFQDN']

@pulumi.input_type
class GatewayFQDNArgs:
    def __init__(__self__, *,
                 backends: pulumi.Input[Sequence[pulumi.Input[str]]],
                 fqdn: pulumi.Input[str],
                 name: pulumi.Input[str],
                 node_id: Any,
                 description: Optional[pulumi.Input[str]] = None,
                 network_name: Optional[pulumi.Input[str]] = None,
                 solution_type: Optional[pulumi.Input[str]] = None,
                 tls_pass_through: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a GatewayFQDN resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] backends: The backends of the gateway proxy. must be in the format ip:port if tls_passthrough is set, otherwise the format should be http://ip[:port]
        :param pulumi.Input[str] fqdn: The fully qualified domain name of the deployed workload
        :param pulumi.Input[str] name: Gateway workload name.  This has to be unique within the deployment. It's required and cannot exceed 50 characters. Must contain only alphanumeric and underscore characters
        :param Any node_id: The gateway's node ID
        :param pulumi.Input[str] description: The description of the virtual machine workload, optional with no restrictions
        :param pulumi.Input[str] network_name: Network name to join, if backend IP is private
        :param pulumi.Input[str] solution_type: The name of the solution for created contract to be consistent across threefold tooling (project name in deployment metadata)
        :param pulumi.Input[bool] tls_pass_through: TLS passthrough controls the TLS termination, if false, the gateway will terminate the TLS, if True, it will only be terminated by the backend service
        """
        pulumi.set(__self__, "backends", backends)
        pulumi.set(__self__, "fqdn", fqdn)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "node_id", node_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if network_name is not None:
            pulumi.set(__self__, "network_name", network_name)
        if solution_type is None:
            solution_type = ''
        if solution_type is not None:
            pulumi.set(__self__, "solution_type", solution_type)
        if tls_pass_through is not None:
            pulumi.set(__self__, "tls_pass_through", tls_pass_through)

    @property
    @pulumi.getter
    def backends(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The backends of the gateway proxy. must be in the format ip:port if tls_passthrough is set, otherwise the format should be http://ip[:port]
        """
        return pulumi.get(self, "backends")

    @backends.setter
    def backends(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "backends", value)

    @property
    @pulumi.getter
    def fqdn(self) -> pulumi.Input[str]:
        """
        The fully qualified domain name of the deployed workload
        """
        return pulumi.get(self, "fqdn")

    @fqdn.setter
    def fqdn(self, value: pulumi.Input[str]):
        pulumi.set(self, "fqdn", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Gateway workload name.  This has to be unique within the deployment. It's required and cannot exceed 50 characters. Must contain only alphanumeric and underscore characters
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def node_id(self) -> Any:
        """
        The gateway's node ID
        """
        return pulumi.get(self, "node_id")

    @node_id.setter
    def node_id(self, value: Any):
        pulumi.set(self, "node_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the virtual machine workload, optional with no restrictions
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def network_name(self) -> Optional[pulumi.Input[str]]:
        """
        Network name to join, if backend IP is private
        """
        return pulumi.get(self, "network_name")

    @network_name.setter
    def network_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "network_name", value)

    @property
    @pulumi.getter
    def solution_type(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the solution for created contract to be consistent across threefold tooling (project name in deployment metadata)
        """
        return pulumi.get(self, "solution_type")

    @solution_type.setter
    def solution_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "solution_type", value)

    @property
    @pulumi.getter
    def tls_pass_through(self) -> Optional[pulumi.Input[bool]]:
        """
        TLS passthrough controls the TLS termination, if false, the gateway will terminate the TLS, if True, it will only be terminated by the backend service
        """
        return pulumi.get(self, "tls_pass_through")

    @tls_pass_through.setter
    def tls_pass_through(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "tls_pass_through", value)


class GatewayFQDN(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backends: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 fqdn: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_name: Optional[pulumi.Input[str]] = None,
                 node_id: Optional[Any] = None,
                 solution_type: Optional[pulumi.Input[str]] = None,
                 tls_pass_through: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        Create a GatewayFQDN resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] backends: The backends of the gateway proxy. must be in the format ip:port if tls_passthrough is set, otherwise the format should be http://ip[:port]
        :param pulumi.Input[str] description: The description of the virtual machine workload, optional with no restrictions
        :param pulumi.Input[str] fqdn: The fully qualified domain name of the deployed workload
        :param pulumi.Input[str] name: Gateway workload name.  This has to be unique within the deployment. It's required and cannot exceed 50 characters. Must contain only alphanumeric and underscore characters
        :param pulumi.Input[str] network_name: Network name to join, if backend IP is private
        :param Any node_id: The gateway's node ID
        :param pulumi.Input[str] solution_type: The name of the solution for created contract to be consistent across threefold tooling (project name in deployment metadata)
        :param pulumi.Input[bool] tls_pass_through: TLS passthrough controls the TLS termination, if false, the gateway will terminate the TLS, if True, it will only be terminated by the backend service
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GatewayFQDNArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a GatewayFQDN resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param GatewayFQDNArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GatewayFQDNArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backends: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 fqdn: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_name: Optional[pulumi.Input[str]] = None,
                 node_id: Optional[Any] = None,
                 solution_type: Optional[pulumi.Input[str]] = None,
                 tls_pass_through: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GatewayFQDNArgs.__new__(GatewayFQDNArgs)

            if backends is None and not opts.urn:
                raise TypeError("Missing required property 'backends'")
            __props__.__dict__["backends"] = backends
            __props__.__dict__["description"] = description
            if fqdn is None and not opts.urn:
                raise TypeError("Missing required property 'fqdn'")
            __props__.__dict__["fqdn"] = fqdn
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["network_name"] = network_name
            if node_id is None and not opts.urn:
                raise TypeError("Missing required property 'node_id'")
            __props__.__dict__["node_id"] = node_id
            if solution_type is None:
                solution_type = ''
            __props__.__dict__["solution_type"] = solution_type
            __props__.__dict__["tls_pass_through"] = tls_pass_through
            __props__.__dict__["contract_id"] = None
            __props__.__dict__["node_deployment_id"] = None
        super(GatewayFQDN, __self__).__init__(
            'threefold:index:GatewayFQDN',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'GatewayFQDN':
        """
        Get an existing GatewayFQDN resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = GatewayFQDNArgs.__new__(GatewayFQDNArgs)

        __props__.__dict__["backends"] = None
        __props__.__dict__["contract_id"] = None
        __props__.__dict__["description"] = None
        __props__.__dict__["fqdn"] = None
        __props__.__dict__["name"] = None
        __props__.__dict__["network_name"] = None
        __props__.__dict__["node_deployment_id"] = None
        __props__.__dict__["node_id"] = None
        __props__.__dict__["solution_type"] = None
        __props__.__dict__["tls_pass_through"] = None
        return GatewayFQDN(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def backends(self) -> pulumi.Output[Sequence[str]]:
        """
        The backends of the gateway proxy. must be in the format ip:port if tls_passthrough is set, otherwise the format should be http://ip[:port]
        """
        return pulumi.get(self, "backends")

    @property
    @pulumi.getter
    def contract_id(self) -> pulumi.Output[int]:
        """
        The deployment ID
        """
        return pulumi.get(self, "contract_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the virtual machine workload, optional with no restrictions
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def fqdn(self) -> pulumi.Output[str]:
        """
        The fully qualified domain name of the deployed workload
        """
        return pulumi.get(self, "fqdn")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Gateway workload name.  This has to be unique within the deployment. It's required and cannot exceed 50 characters. Must contain only alphanumeric and underscore characters
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def network_name(self) -> pulumi.Output[Optional[str]]:
        """
        Network name to join, if backend IP is private
        """
        return pulumi.get(self, "network_name")

    @property
    @pulumi.getter
    def node_deployment_id(self) -> pulumi.Output[Mapping[str, int]]:
        """
        Mapping from each node to its deployment ID
        """
        return pulumi.get(self, "node_deployment_id")

    @property
    @pulumi.getter
    def node_id(self) -> pulumi.Output[Any]:
        """
        The gateway's node ID
        """
        return pulumi.get(self, "node_id")

    @property
    @pulumi.getter
    def solution_type(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the solution for created contract to be consistent across threefold tooling (project name in deployment metadata)
        """
        return pulumi.get(self, "solution_type")

    @property
    @pulumi.getter
    def tls_pass_through(self) -> pulumi.Output[Optional[bool]]:
        """
        TLS passthrough controls the TLS termination, if false, the gateway will terminate the TLS, if True, it will only be terminated by the backend service
        """
        return pulumi.get(self, "tls_pass_through")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProviderArgs', 'Provider']

@pulumi.input_type
class ProviderArgs:
    def __init__(__self__, *,
                 graphql_url: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 key_type: Optional[pulumi.Input[str]] = None,
                 mnemonic: Optional[pulumi.Input[str]] = None,
                 network: Optional[pulumi.Input[str]] = None,
                 proxy_url: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 relay_url: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 rmb_timeout: Optional[pulumi.Input[str]] = None,
                 substrate_url: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a Provider resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] graphql_url: The graphql urls, example: https://graphql.grid.tf/graphql
        :param pulumi.Input[str] key_type: The key type registered on substrate (ed25519 or sr25519).
        :param pulumi.Input[str] mnemonic: The mnemonic of the user. It is very secret.
        :param pulumi.Input[str] network: The network to deploy on.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] proxy_url: The proxy urls, example: https://gridproxy.grid.tf/
        :param pulumi.Input[Sequence[pulumi.Input[str]]] relay_url: The relay urls, example: wss://relay.grid.tf
        :param pulumi.Input[str] rmb_timeout: The timeout duration in seconds for rmb calls
        :param pulumi.Input[Sequence[pulumi.Input[str]]] substrate_url: The substrate url, example: wss://tfchain.grid.tf/ws
        """
        if graphql_url is not None:
            pulumi.set(__self__, "graphql_url", graphql_url)
        if key_type is None:
            key_type = (_utilities.get_env('') or 'sr25519')
        if key_type is not None:
            pulumi.set(__self__, "key_type", key_type)
        if mnemonic is None:
            mnemonic = (_utilities.get_env('') or '')
        if mnemonic is not None:
            pulumi.set(__self__, "mnemonic", mnemonic)
        if network is None:
            network = (_utilities.get_env('') or '')
        if network is not None:
            pulumi.set(__self__, "network", network)
        if proxy_url is not None:
            pulumi.set(__self__, "proxy_url", proxy_url)
        if relay_url is not None:
            pulumi.set(__self__, "relay_url", relay_url)
        if rmb_timeout is not None:
            pulumi.set(__self__, "rmb_timeout", rmb_timeout)
        if substrate_url is not None:
            pulumi.set(__self__, "substrate_url", substrate_url)

    @property
    @pulumi.getter
    def graphql_url(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The graphql urls, example: https://graphql.grid.tf/graphql
        """
        return pulumi.get(self, "graphql_url")

    @graphql_url.setter
    def graphql_url(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "graphql_url", value)

    @property
    @pulumi.getter
    def key_type(self) -> Optional[pulumi.Input[str]]:
        """
        The key type registered on substrate (ed25519 or sr25519).
        """
        return pulumi.get(self, "key_type")

    @key_type.setter
    def key_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key_type", value)

    @property
    @pulumi.getter
    def mnemonic(self) -> Optional[pulumi.Input[str]]:
        """
        The mnemonic of the user. It is very secret.
        """
        return pulumi.get(self, "mnemonic")

    @mnemonic.setter
    def mnemonic(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mnemonic", value)

    @property
    @pulumi.getter
    def network(self) -> Optional[pulumi.Input[str]]:
        """
        The network to deploy on.
        """
        return pulumi.get(self, "network")

    @network.setter
    def network(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "network", value)

    @property
    @pulumi.getter
    def proxy_url(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The proxy urls, example: https://gridproxy.grid.tf/
        """
        return pulumi.get(self, "proxy_url")

    @proxy_url.setter
    def proxy_url(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "proxy_url", value)

    @property
    @pulumi.getter
    def relay_url(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The relay urls, example: wss://relay.grid.tf
        """
        return pulumi.get(self, "relay_url")

    @relay_url.setter
    def relay_url(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "relay_url", value)

    @property
    @pulumi.getter
    def rmb_timeout(self) -> Optional[pulumi.Input[str]]:
        """
        The timeout duration in seconds for rmb calls
        """
        return pulumi.get(self, "rmb_timeout")

    @rmb_timeout.setter
    def rmb_timeout(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rmb_timeout", value)

    @property
    @pulumi.getter
    def substrate_url(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The substrate url, example: wss://tfchain.grid.tf/ws
        """
        return pulumi.get(self, "substrate_url")

    @substrate_url.setter
    def substrate_url(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "substrate_url", value)


class Provider(pulumi.ProviderResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 graphql_url: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 key_type: Optional[pulumi.Input[str]] = None,
                 mnemonic: Optional[pulumi.Input[str]] = None,
                 network: Optional[pulumi.Input[str]] = None,
                 proxy_url: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 relay_url: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 rmb_timeout: Optional[pulumi.Input[str]] = None,
                 substrate_url: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Create a Threefold resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] graphql_url: The graphql urls, example: https://graphql.grid.tf/graphql
        :param pulumi.Input[str] key_type: The key type registered on substrate (ed25519 or sr25519).
        :param pulumi.Input[str] mnemonic: The mnemonic of the user. It is very secret.
        :param pulumi.Input[str] network: The network to deploy on.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] proxy_url: The proxy urls, example: https://gridproxy.grid.tf/
        :param pulumi.Input[Sequence[pulumi.Input[str]]] relay_url: The relay urls, example: wss://relay.grid.tf
        :param pulumi.Input[str] rmb_timeout: The timeout duration in seconds for rmb calls
        :param pulumi.Input[Sequence[pulumi.Input[str]]] substrate_url: The substrate url, example: wss://tfchain.grid.tf/ws
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProviderArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a Threefold resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param ProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 graphql_url: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 key_type: Optional[pulumi.Input[str]] = None,
                 mnemonic: Optional[pulumi.Input[str]] = None,
                 network: Optional[pulumi.Input[str]] = None,
                 proxy_url: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 relay_url: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 rmb_timeout: Optional[pulumi.Input[str]] = None,
                 substrate_url: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderArgs.__new__(ProviderArgs)

            __props__.__dict__["graphql_url"] = pulumi.Output.from_input(graphql_url).apply(pulumi.runtime.to_json) if graphql_url is not None else None
            if key_type is None:
                key_type = (_utilities.get_env('') or 'sr25519')
            __props__.__dict__["key_type"] = key_type
            if mnemonic is None:
                mnemonic = (_utilities.get_env('') or '')
            __props__.__dict__["mnemonic"] = None if mnemonic is None else pulumi.Output.secret(mnemonic)
            if network is None:
                network = (_utilities.get_env('') or '')
            __props__.__dict__["network"] = network
            __props__.__dict__["proxy_url"] = pulumi.Output.from_input(proxy_url).apply(pulumi.runtime.to_json) if proxy_url is not None else None
            __props__.__dict__["relay_url"] = pulumi.Output.from_input(relay_url).apply(pulumi.runtime.to_json) if relay_url is not None else None
            __props__.__dict__["rmb_timeout"] = rmb_timeout
            __props__.__dict__["substrate_url"] = pulumi.Output.from_input(substrate_url).apply(pulumi.runtime.to_json) if substrate_url is not None else None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["mnemonic"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Provider, __self__).__init__(
            'threefold',
            resource_name,
            __props__,
            opts)

    @property
    @pulumi.getter
    def key_type(self) -> pulumi.Output[Optional[str]]:
        """
        The key type registered on substrate (ed25519 or sr25519).
        """
        return pulumi.get(self, "key_type")

    @property
    @pulumi.getter
    def mnemonic(self) -> pulumi.Output[Optional[str]]:
        """
        The mnemonic of the user. It is very secret.
        """
        return pulumi.get(self, "mnemonic")

    @property
    @pulumi.getter
    def network(self) -> pulumi.Output[Optional[str]]:
        """
        The network to deploy on.
        """
        return pulumi.get(self, "network")

    @property
    @pulumi.getter
    def rmb_timeout(self) -> pulumi.Output[Optional[str]]:
        """
        The timeout duration in seconds for rmb calls
        """
        return pulumi.get(self, "rmb_timeout")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('threefold')


class _ExportableConfig(types.ModuleType):
    @property
    def graphql_url(self) -> Optional[str]:
        """
        The graphql urls, example: https://graphql.grid.tf/graphql
        """
        return __config__.get('graphql_url')

    @property
    def key_type(self) -> str:
        """
        The key type registered on substrate (ed25519 or sr25519).
        """
        return __config__.get('key_type') or (_utilities.get_env('') or 'sr25519')

    @property
    def mnemonic(self) -> str:
        """
        The mnemonic of the user. It is very secret.
        """
        return __config__.get('mnemonic') or (_utilities.get_env('') or '')

    @property
    def network(self) -> str:
        """
        The network to deploy on.
        """
        return __config__.get('network') or (_utilities.get_env('') or '')

    @property
    def proxy_url(self) -> Optional[str]:
        """
        The proxy urls, example: https://gridproxy.grid.tf/
        """
        return __config__.get('proxy_url')

    @property
    def relay_url(self) -> Optional[str]:
        """
        The relay urls, example: wss://relay.grid.tf
        """
        return __config__.get('relay_url')

    @property
    def rmb_timeout(self) -> Optional[str]:
        """
        The timeout duration in seconds for rmb calls
        """
        return __config__.get('rmb_timeout')

    @property
    def substrate_url(self) -> Optional[str]:
        """
        The substrate url, example: wss://tfchain.grid.tf/ws
        """
        return __config__.get('substrate_url')




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['SchedulerArgs', 'Scheduler']

@pulumi.input_type
class SchedulerArgs:
    def __init__(__self__, *,
                 certification_type: Optional[pulumi.Input[str]] = None,
                 city: Optional[pulumi.Input[str]] = None,
                 country: Optional[pulumi.Input[str]] = None,
                 dedicated: Optional[pulumi.Input[bool]] = None,
                 domain: Optional[pulumi.Input[bool]] = None,
                 farm_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 farm_name: Optional[pulumi.Input[str]] = None,
                 free_ips: Optional[pulumi.Input[int]] = None,
                 gpu_available: Optional[pulumi.Input[bool]] = None,
                 gpu_device_id: Optional[pulumi.Input[str]] = None,
                 gpu_device_name: Optional[pulumi.Input[str]] = None,
                 gpu_vendor_id: Optional[pulumi.Input[str]] = None,
                 gpu_vendor_name: Optional[pulumi.Input[str]] = None,
                 has_gpu: Optional[pulumi.Input[bool]] = None,
                 hru: Optional[pulumi.Input[int]] = None,
                 ipv4: Optional[pulumi.Input[bool]] = None,
                 ipv6: Optional[pulumi.Input[bool]] = None,
                 mru: Optional[pulumi.Input[int]] = None,
                 node_id: Optional[pulumi.Input[int]] = None,
                 rentable: Optional[pulumi.Input[bool]] = None,
                 rented: Optional[pulumi.Input[bool]] = None,
                 sru: Optional[pulumi.Input[int]] = None,
                 twin_id: Optional[pulumi.Input[int]] = None,
                 wireguard: Optional[pulumi.Input[bool]] = None,
                 ygg: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a Scheduler resource.
        """
        if certification_type is not None:
            pulumi.set(__self__, "certification_type", certification_type)
        if city is not None:
            pulumi.set(__self__, "city", city)
        if country is not None:
            pulumi.set(__self__, "country", country)
        if dedicated is not None:
            pulumi.set(__self__, "dedicated", dedicated)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if farm_ids is not None:
            pulumi.set(__self__, "farm_ids", farm_ids)
        if farm_name is not None:
            pulumi.set(__self__, "farm_name", farm_name)
        if free_ips is not None:
            pulumi.set(__self__, "free_ips", free_ips)
        if gpu_available is not None:
            pulumi.set(__self__, "gpu_available", gpu_available)
        if gpu_device_id is not None:
            pulumi.set(__self__, "gpu_device_id", gpu_device_id)
        if gpu_device_name is not None:
            pulumi.set(__self__, "gpu_device_name", gpu_device_name)
        if gpu_vendor_id is not None:
            pulumi.set(__self__, "gpu_vendor_id", gpu_vendor_id)
        if gpu_vendor_name is not None:
            pulumi.set(__self__, "gpu_vendor_name", gpu_vendor_name)
        if has_gpu is not None:
            pulumi.set(__self__, "has_gpu", has_gpu)
        if hru is not None:
            pulumi.set(__self__, "hru", hru)
        if ipv4 is not None:
            pulumi.set(__self__, "ipv4", ipv4)
        if ipv6 is not None:
            pulumi.set(__self__, "ipv6", ipv6)
        if mru is not None:
            pulumi.set(__self__, "mru", mru)
        if node_id is not None:
            pulumi.set(__self__, "node_id", node_id)
        if rentable is not None:
            pulumi.set(__self__, "rentable", rentable)
        if rented is not None:
            pulumi.set(__self__, "rented", rented)
        if sru is not None:
            pulumi.set(__self__, "sru", sru)
        if twin_id is not None:
            pulumi.set(__self__, "twin_id", twin_id)
        if wireguard is not None:
            pulumi.set(__self__, "wireguard", wireguard)
        if ygg is not None:
            pulumi.set(__self__, "ygg", ygg)

    @property
    @pulumi.getter
    def certification_type(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "certification_type")

    @certification_type.setter
    def certification_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "certification_type", value)

    @property
    @pulumi.getter
    def city(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "city")

    @city.setter
    def city(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "city", value)

    @property
    @pulumi.getter
    def country(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "country")

    @country.setter
    def country(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "country", value)

    @property
    @pulumi.getter
    def dedicated(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "dedicated")

    @dedicated.setter
    def dedicated(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dedicated", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter
    def farm_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        return pulumi.get(self, "farm_ids")

    @farm_ids.setter
    def farm_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "farm_ids", value)

    @property
    @pulumi.getter
    def farm_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "farm_name")

    @farm_name.setter
    def farm_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "farm_name", value)

    @property
    @pulumi.getter
    def free_ips(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "free_ips")

    @free_ips.setter
    def free_ips(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "free_ips", value)

    @property
    @pulumi.getter
    def gpu_available(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "gpu_available")

    @gpu_available.setter
    def gpu_available(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "gpu_available", value)

    @property
    @pulumi.getter
    def gpu_device_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "gpu_device_id")

    @gpu_device_id.setter
    def gpu_device_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gpu_device_id", value)

    @property
    @pulumi.getter
    def gpu_device_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "gpu_device_name")

    @gpu_device_name.setter
    def gpu_device_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gpu_device_name", value)

    @property
    @pulumi.getter
    def gpu_vendor_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "gpu_vendor_id")

    @gpu_vendor_id.setter
    def gpu_vendor_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gpu_vendor_id", value)

    @property
    @pulumi.getter
    def gpu_vendor_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "gpu_vendor_name")

    @gpu_vendor_name.setter
    def gpu_vendor_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gpu_vendor_name", value)

    @property
    @pulumi.getter
    def has_gpu(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "has_gpu")

    @has_gpu.setter
    def has_gpu(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "has_gpu", value)

    @property
    @pulumi.getter
    def hru(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "hru")

    @hru.setter
    def hru(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "hru", value)

    @property
    @pulumi.getter
    def ipv4(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "ipv4")

    @ipv4.setter
    def ipv4(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "ipv4", value)

    @property
    @pulumi.getter
    def ipv6(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "ipv6")

    @ipv6.setter
    def ipv6(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "ipv6", value)

    @property
    @pulumi.getter
    def mru(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "mru")

    @mru.setter
    def mru(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "mru", value)

    @property
    @pulumi.getter
    def node_id(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "node_id")

    @node_id.setter
    def node_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "node_id", value)

    @property
    @pulumi.getter
    def rentable(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "rentable")

    @rentable.setter
    def rentable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "rentable", value)

    @property
    @pulumi.getter
    def rented(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "rented")

    @rented.setter
    def rented(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "rented", value)

    @property
    @pulumi.getter
    def sru(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "sru")

    @sru.setter
    def sru(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "sru", value)

    @property
    @pulumi.getter
    def twin_id(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "twin_id")

    @twin_id.setter
    def twin_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "twin_id", value)

    @property
    @pulumi.getter
    def wireguard(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "wireguard")

    @wireguard.setter
    def wireguard(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "wireguard", value)

    @property
    @pulumi.getter
    def ygg(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "ygg")

    @ygg.setter
    def ygg(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "ygg", value)


class Scheduler(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 certification_type: Optional[pulumi.Input[str]] = None,
                 city: Optional[pulumi.Input[str]] = None,
                 country: Optional[pulumi.Input[str]] = None,
                 dedicated: Optional[pulumi.Input[bool]] = None,
                 domain: Optional[pulumi.Input[bool]] = None,
                 farm_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 farm_name: Optional[pulumi.Input[str]] = None,
                 free_ips: Optional[pulumi.Input[int]] = None,
                 gpu_available: Optional[pulumi.Input[bool]] = None,
                 gpu_device_id: Optional[pulumi.Input[str]] = None,
                 gpu_device_name: Optional[pulumi.Input[str]] = None,
                 gpu_vendor_id: Optional[pulumi.Input[str]] = None,
                 gpu_vendor_name: Optional[pulumi.Input[str]] = None,
                 has_gpu: Optional[pulumi.Input[bool]] = None,
                 hru: Optional[pulumi.Input[int]] = None,
                 ipv4: Optional[pulumi.Input[bool]] = None,
                 ipv6: Optional[pulumi.Input[bool]] = None,
                 mru: Optional[pulumi.Input[int]] = None,
                 node_id: Optional[pulumi.Input[int]] = None,
                 rentable: Optional[pulumi.Input[bool]] = None,
                 rented: Optional[pulumi.Input[bool]] = None,
                 sru: Optional[pulumi.Input[int]] = None,
                 twin_id: Optional[pulumi.Input[int]] = None,
                 wireguard: Optional[pulumi.Input[bool]] = None,
                 ygg: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        Create a Scheduler resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[SchedulerArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a Scheduler resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param SchedulerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SchedulerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 certification_type: Optional[pulumi.Input[str]] = None,
                 city: Optional[pulumi.Input[str]] = None,
                 country: Optional[pulumi.Input[str]] = None,
                 dedicated: Optional[pulumi.Input[bool]] = None,
                 domain: Optional[pulumi.Input[bool]] = None,
                 farm_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 farm_name: Optional[pulumi.Input[str]] = None,
                 free_ips: Optional[pulumi.Input[int]] = None,
                 gpu_available: Optional[pulumi.Input[bool]] = None,
                 gpu_device_id: Optional[pulumi.Input[str]] = None,
                 gpu_device_name: Optional[pulumi.Input[str]] = None,
                 gpu_vendor_id: Optional[pulumi.Input[str]] = None,
                 gpu_vendor_name: Optional[pulumi.Input[str]] = None,
                 has_gpu: Optional[pulumi.Input[bool]] = None,
                 hru: Optional[pulumi.Input[int]] = None,
                 ipv4: Optional[pulumi.Input[bool]] = None,
                 ipv6: Optional[pulumi.Input[bool]] = None,
                 mru: Optional[pulumi.Input[int]] = None,
                 node_id: Optional[pulumi.Input[int]] = None,
                 rentable: Optional[pulumi.Input[bool]] = None,
                 rented: Optional[pulumi.Input[bool]] = None,
                 sru: Optional[pulumi.Input[int]] = None,
                 twin_id: Optional[pulumi.Input[int]] = None,
                 wireguard: Optional[pulumi.Input[bool]] = None,
                 ygg: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SchedulerArgs.__new__(SchedulerArgs)

            __props__.__dict__["certification_type"] = certification_type
            __props__.__dict__["city"] = city
            __props__.__dict__["country"] = country
            __props__.__dict__["dedicated"] = dedicated
            __props__.__dict__["domain"] = domain
            __props__.__dict__["farm_ids"] = farm_ids
            __props__.__dict__["farm_name"] = farm_name
            __props__.__dict__["free_ips"] = free_ips
            __props__.__dict__["gpu_available"] = gpu_available
            __props__.__dict__["gpu_device_id"] = gpu_device_id
            __props__.__dict__["gpu_device_name"] = gpu_device_name
            __props__.__dict__["gpu_vendor_id"] = gpu_vendor_id
            __props__.__dict__["gpu_vendor_name"] = gpu_vendor_name
            __props__.__dict__["has_gpu"] = has_gpu
            __props__.__dict__["hru"] = hru
            __props__.__dict__["ipv4"] = ipv4
            __props__.__dict__["ipv6"] = ipv6
            __props__.__dict__["mru"] = mru
            __props__.__dict__["node_id"] = node_id
            __props__.__dict__["rentable"] = rentable
            __props__.__dict__["rented"] = rented
            __props__.__dict__["sru"] = sru
            __props__.__dict__["twin_id"] = twin_id
            __props__.__dict__["wireguard"] = wireguard
            __props__.__dict__["ygg"] = ygg
            __props__.__dict__["nodes"] = None
        super(Scheduler, __self__).__init__(
            'threefold:index:Scheduler',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'Scheduler':
        """
        Get an existing Scheduler resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = SchedulerArgs.__new__(SchedulerArgs)

        __props__.__dict__["certification_type"] = None
        __props__.__dict__["city"] = None
        __props__.__dict__["country"] = None
        __props__.__dict__["dedicated"] = None
        __props__.__dict__["domain"] = None
        __props__.__dict__["farm_ids"] = None
        __props__.__dict__["farm_name"] = None
        __props__.__dict__["free_ips"] = None
        __props__.__dict__["gpu_available"] = None
        __props__.__dict__["gpu_device_id"] = None
        __props__.__dict__["gpu_device_name"] = None
        __props__.__dict__["gpu_vendor_id"] = None
        __props__.__dict__["gpu_vendor_name"] = None
        __props__.__dict__["has_gpu"] = None
        __props__.__dict__["hru"] = None
        __props__.__dict__["ipv4"] = None
        __props__.__dict__["ipv6"] = None
        __props__.__dict__["mru"] = None
        __props__.__dict__["node_id"] = None
        __props__.__dict__["nodes"] = None
        __props__.__dict__["rentable"] = None
        __props__.__dict__["rented"] = None
        __props__.__dict__["sru"] = None
        __props__.__dict__["twin_id"] = None
        __props__.__dict__["wireguard"] = None
        __props__.__dict__["ygg"] = None
        return Scheduler(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def certification_type(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "certification_type")

    @property
    @pulumi.getter
    def city(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "city")

    @property
    @pulumi.getter
    def country(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "country")

    @property
    @pulumi.getter
    def dedicated(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "dedicated")

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter
    def farm_ids(self) -> pulumi.Output[Optional[Sequence[int]]]:
        return pulumi.get(self, "farm_ids")

    @property
    @pulumi.getter
    def farm_name(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "farm_name")

    @property
    @pulumi.getter
    def free_ips(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "free_ips")

    @property
    @pulumi.getter
    def gpu_available(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "gpu_available")

    @property
    @pulumi.getter
    def gpu_device_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "gpu_device_id")

    @property
    @pulumi.getter
    def gpu_device_name(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "gpu_device_name")

    @property
    @pulumi.getter
    def gpu_vendor_id(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "gpu_vendor_id")

    @property
    @pulumi.getter
    def gpu_vendor_name(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "gpu_vendor_name")

    @property
    @pulumi.getter
    def has_gpu(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "has_gpu")

    @property
    @pulumi.getter
    def hru(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "hru")

    @property
    @pulumi.getter
    def ipv4(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "ipv4")

    @property
    @pulumi.getter
    def ipv6(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "ipv6")

    @property
    @pulumi.getter
    def mru(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "mru")

    @property
    @pulumi.getter
    def node_id(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "node_id")

    @property
    @pulumi.getter
    def nodes(self) -> pulumi.Output[Sequence[int]]:
        return pulumi.get(self, "nodes")

    @property
    @pulumi.getter
    def rentable(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "rentable")

    @property
    @pulumi.getter
    def rented(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "rented")

    @property
    @pulumi.getter
    def sru(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "sru")

    @property
    @pulumi.getter
    def twin_id(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "twin_id")

    @property
    @pulumi.getter
    def wireguard(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "wireguard")

    @property
    @pulumi.getter
    def ygg(self) -> pulumi.Output[Optional[bool]]:
        return pulumi.get(self, "ygg")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DeploymentArgs', 'Deployment']

@pulumi.input_type
class DeploymentArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 node_id: Any,
                 disks: Optional[pulumi.Input[Sequence[pulumi.Input['DiskArgs']]]] = None,
                 network_name: Optional[pulumi.Input[str]] = None,
                 qsfs: Optional[pulumi.Input[Sequence[pulumi.Input['QSFSInputArgs']]]] = None,
                 solution_provider: Optional[pulumi.Input[int]] = None,
                 solution_type: Optional[pulumi.Input[str]] = None,
                 vms: Optional[pulumi.Input[Sequence[pulumi.Input['VMInputArgs']]]] = None,
                 zdbs: Optional[pulumi.Input[Sequence[pulumi.Input['ZDBInputArgs']]]] = None):
        """
        The set of arguments for constructing a Deployment resource.
        :param pulumi.Input[str] name: The name of the deployment, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported
        :param Any node_id: The node ID to deploy on, required and should match the requested resources
        :param pulumi.Input[Sequence[pulumi.Input['DiskArgs']]] disks: The disks requested to be included in the deployment
        :param pulumi.Input[str] network_name: The name of the network, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported. Network must exist
        :param pulumi.Input[Sequence[pulumi.Input['QSFSInputArgs']]] qsfs: The qsfs instances requested to be included in the deployment
        :param pulumi.Input[int] solution_provider: ID for the deployed solution which allows the creator of the solution to gain a percentage of the rewards
        :param pulumi.Input[str] solution_type: The name of the solution for created contract to be consistent across threefold tooling (project name in deployment metadata)
        :param pulumi.Input[Sequence[pulumi.Input['VMInputArgs']]] vms: The vms requested to be included in the deployment
        :param pulumi.Input[Sequence[pulumi.Input['ZDBInputArgs']]] zdbs: The zdbs requested to be included in the deployment
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "node_id", node_id)
        if disks is not None:
            pulumi.set(__self__, "disks", disks)
        if network_name is not None:
            pulumi.set(__self__, "network_name", network_name)
        if qsfs is not None:
            pulumi.set(__self__, "qsfs", qsfs)
        if solution_provider is not None:
            pulumi.set(__self__, "solution_provider", solution_provider)
        if solution_type is None:
            solution_type = 'vm/'
        if solution_type is not None:
            pulumi.set(__self__, "solution_type", solution_type)
        if vms is not None:
            pulumi.set(__self__, "vms", vms)
        if zdbs is not None:
            pulumi.set(__self__, "zdbs", zdbs)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        The name of the deployment, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def node_id(self) -> Any:
        """
        The node ID to deploy on, required and should match the requested resources
        """
        return pulumi.get(self, "node_id")

    @node_id.setter
    def node_id(self, value: Any):
        pulumi.set(self, "node_id", value)

    @property
    @pulumi.getter
    def disks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DiskArgs']]]]:
        """
        The disks requested to be included in the deployment
        """
        return pulumi.get(self, "disks")

    @disks.setter
    def disks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DiskArgs']]]]):
        pulumi.set(self, "disks", value)

    @property
    @pulumi.getter
    def network_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the network, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported. Network must exist
        """
        return pulumi.get(self, "network_name")

    @network_name.setter
    def network_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "network_name", value)

    @property
    @pulumi.getter
    def qsfs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['QSFSInputArgs']]]]:
        """
        The qsfs instances requested to be included in the deployment
        """
        return pulumi.get(self, "qsfs")

    @qsfs.setter
    def qsfs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['QSFSInputArgs']]]]):
        pulumi.set(self, "qsfs", value)

    @property
    @pulumi.getter
    def solution_provider(self) -> Optional[pulumi.Input[int]]:
        """
        ID for the deployed solution which allows the creator of the solution to gain a percentage of the rewards
        """
        return pulumi.get(self, "solution_provider")

    @solution_provider.setter
    def solution_provider(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "solution_provider", value)

    @property
    @pulumi.getter
    def solution_type(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the solution for created contract to be consistent across threefold tooling (project name in deployment metadata)
        """
        return pulumi.get(self, "solution_type")

    @solution_type.setter
    def solution_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "solution_type", value)

    @property
    @pulumi.getter
    def vms(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VMInputArgs']]]]:
        """
        The vms requested to be included in the deployment
        """
        return pulumi.get(self, "vms")

    @vms.setter
    def vms(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VMInputArgs']]]]):
        pulumi.set(self, "vms", value)

    @property
    @pulumi.getter
    def zdbs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ZDBInputArgs']]]]:
        """
        The zdbs requested to be included in the deployment
        """
        return pulumi.get(self, "zdbs")

    @zdbs.setter
    def zdbs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ZDBInputArgs']]]]):
        pulumi.set(self, "zdbs", value)


class Deployment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 disks: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DiskArgs']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_name: Optional[pulumi.Input[str]] = None,
                 node_id: Optional[Any] = None,
                 qsfs: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['QSFSInputArgs']]]]] = None,
                 solution_provider: Optional[pulumi.Input[int]] = None,
                 solution_type: Optional[pulumi.Input[str]] = None,
                 vms: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VMInputArgs']]]]] = None,
                 zdbs: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ZDBInputArgs']]]]] = None,
                 __props__=None):
        """
        Create a Deployment resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DiskArgs']]]] disks: The disks requested to be included in the deployment
        :param pulumi.Input[str] name: The name of the deployment, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported
        :param pulumi.Input[str] network_name: The name of the network, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported. Network must exist
        :param Any node_id: The node ID to deploy on, required and should match the requested resources
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['QSFSInputArgs']]]] qsfs: The qsfs instances requested to be included in the deployment
        :param pulumi.Input[int] solution_provider: ID for the deployed solution which allows the creator of the solution to gain a percentage of the rewards
        :param pulumi.Input[str] solution_type: The name of the solution for created contract to be consistent across threefold tooling (project name in deployment metadata)
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VMInputArgs']]]] vms: The vms requested to be included in the deployment
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ZDBInputArgs']]]] zdbs: The zdbs requested to be included in the deployment
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DeploymentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a Deployment resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param DeploymentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DeploymentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 disks: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DiskArgs']]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_name: Optional[pulumi.Input[str]] = None,
                 node_id: Optional[Any] = None,
                 qsfs: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['QSFSInputArgs']]]]] = None,
                 solution_provider: Optional[pulumi.Input[int]] = None,
                 solution_type: Optional[pulumi.Input[str]] = None,
                 vms: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VMInputArgs']]]]] = None,
                 zdbs: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ZDBInputArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DeploymentArgs.__new__(DeploymentArgs)

            __props__.__dict__["disks"] = disks
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["network_name"] = network_name
            if node_id is None and not opts.urn:
                raise TypeError("Missing required property 'node_id'")
            __props__.__dict__["node_id"] = node_id
            __props__.__dict__["qsfs"] = qsfs
            __props__.__dict__["solution_provider"] = solution_provider
            if solution_type is None:
                solution_type = 'vm/'
            __props__.__dict__["solution_type"] = solution_type
            __props__.__dict__["vms"] = vms
            __props__.__dict__["zdbs"] = zdbs
            __props__.__dict__["contract_id"] = None
            __props__.__dict__["ip_range"] = None
            __props__.__dict__["node_deployment_id"] = None
            __props__.__dict__["qsfs_computed"] = None
            __props__.__dict__["vms_computed"] = None
            __props__.__dict__["zdbs_computed"] = None
        super(Deployment, __self__).__init__(
            'threefold:index:Deployment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'Deployment':
        """
        Get an existing Deployment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = DeploymentArgs.__new__(DeploymentArgs)

        __props__.__dict__["contract_id"] = None
        __props__.__dict__["disks"] = None
        __props__.__dict__["ip_range"] = None
        __props__.__dict__["name"] = None
        __props__.__dict__["network_name"] = None
        __props__.__dict__["node_deployment_id"] = None
        __props__.__dict__["node_id"] = None
        __props__.__dict__["qsfs"] = None
        __props__.__dict__["qsfs_computed"] = None
        __props__.__dict__["solution_provider"] = None
        __props__.__dict__["solution_type"] = None
        __props__.__dict__["vms"] = None
        __props__.__dict__["vms_computed"] = None
        __props__.__dict__["zdbs"] = None
        __props__.__dict__["zdbs_computed"] = None
        return Deployment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def contract_id(self) -> pulumi.Output[int]:
        """
        The deployment ID
        """
        return pulumi.get(self, "contract_id")

    @property
    @pulumi.getter
    def disks(self) -> pulumi.Output[Optional[Sequence['outputs.Disk']]]:
        """
        The disks requested to be included in the deployment
        """
        return pulumi.get(self, "disks")

    @property
    @pulumi.getter
    def ip_range(self) -> pulumi.Output[str]:
        """
        IP range of the node for the wireguard network (e.g. 10.1.2.0/24). Has to have a subnet mask of 24
        """
        return pulumi.get(self, "ip_range")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the deployment, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def network_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the network, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported. Network must exist
        """
        return pulumi.get(self, "network_name")

    @property
    @pulumi.getter
    def node_deployment_id(self) -> pulumi.Output[Mapping[str, int]]:
        """
        Mapping from each node to its deployment ID
        """
        return pulumi.get(self, "node_deployment_id")

    @property
    @pulumi.getter
    def node_id(self) -> pulumi.Output[Any]:
        """
        The node ID to deploy on, required and should match the requested resources
        """
        return pulumi.get(self, "node_id")

    @property
    @pulumi.getter
    def qsfs(self) -> pulumi.Output[Optional[Sequence['outputs.QSFSInput']]]:
        """
        The qsfs output instances requested to be included in the deployment
        """
        return pulumi.get(self, "qsfs")

    @property
    @pulumi.getter
    def qsfs_computed(self) -> pulumi.Output[Sequence['outputs.QSFSComputed']]:
        return pulumi.get(self, "qsfs_computed")

    @property
    @pulumi.getter
    def solution_provider(self) -> pulumi.Output[Optional[int]]:
        """
        ID for the deployed solution which allows the creator of the solution to gain a percentage of the rewards
        """
        return pulumi.get(self, "solution_provider")

    @property
    @pulumi.getter
    def solution_type(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the solution for created contract to be consistent across threefold tooling (project name in deployment metadata)
        """
        return pulumi.get(self, "solution_type")

    @property
    @pulumi.getter
    def vms(self) -> pulumi.Output[Optional[Sequence['outputs.VMInput']]]:
        """
        The vms output requested to be included in the deployment
        """
        return pulumi.get(self, "vms")

    @property
    @pulumi.getter
    def vms_computed(self) -> pulumi.Output[Sequence['outputs.VMComputed']]:
        return pulumi.get(self, "vms_computed")

    @property
    @pulumi.getter
    def zdbs(self) -> pulumi.Output[Optional[Sequence['outputs.ZDBInput']]]:
        """
        The zdbs output requested to be included in the deployment
        """
        return pulumi.get(self, "zdbs")

    @property
    @pulumi.getter
    def zdbs_computed(self) -> pulumi.Output[Sequence['outputs.ZDBComputed']]:
        return pulumi.get(self, "zdbs_computed")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'Backend',
    'Disk',
    'Group',
    'K8sNodeInput',
    'Metadata',
    'Mount',
    'QSFSComputed',
    'QSFSInput',
    'VMComputed',
    'VMInput',
    'ZDBComputed',
    'ZDBInput',
    'Zlog',
]

@pulumi.output_type
class Backend(dict):
    def __init__(__self__, *,
                 address: str,
                 namespace: str,
                 password: str):
        """
        :param str address: Address of backend ZDB (e.g. [300:a582:c60c:df75:f6da:8a92:d5ed:71ad]:9900 or 60.60.60.60:9900)
        :param str namespace: ZDB namespace
        :param str password: Namespace password
        """
        pulumi.set(__self__, "address", address)
        pulumi.set(__self__, "namespace", namespace)
        pulumi.set(__self__, "password", password)

    @property
    @pulumi.getter
    def address(self) -> str:
        """
        Address of backend ZDB (e.g. [300:a582:c60c:df75:f6da:8a92:d5ed:71ad]:9900 or 60.60.60.60:9900)
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter
    def namespace(self) -> str:
        """
        ZDB namespace
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter
    def password(self) -> str:
        """
        Namespace password
        """
        return pulumi.get(self, "password")


@pulumi.output_type
class Disk(dict):
    def __init__(__self__, *,
                 name: str,
                 size: int,
                 description: Optional[str] = None):
        """
        :param str name: The name of the disk workload, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported
        :param int size: The disk size in GB (type SSD)
        :param str description: The description of the disk workload, optional with no restrictions
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "size", size)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the disk workload, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def size(self) -> int:
        """
        The disk size in GB (type SSD)
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        The description of the disk workload, optional with no restrictions
        """
        return pulumi.get(self, "description")


@pulumi.output_type
class Group(dict):
    def __init__(__self__, *,
                 backends: Optional[Sequence['outputs.Backend']] = None):
        """
        :param Sequence['Backend'] backends: List of ZDB backends configurations
        """
        if backends is not None:
            pulumi.set(__self__, "backends", backends)

    @property
    @pulumi.getter
    def backends(self) -> Optional[Sequence['outputs.Backend']]:
        """
        List of ZDB backends configurations
        """
        return pulumi.get(self, "backends")


@pulumi.output_type
class K8sNodeInput(dict):
    def __init__(__self__, *,
                 cpu: int,
                 disk_size: int,
                 memory: int,
                 name: str,
                 network_name: str,
                 node_id: Any,
                 description: Optional[str] = None,
                 entry_point: Optional[str] = None,
                 flist: Optional[str] = None,
                 flist_checksum: Optional[str] = None,
                 mycelium: Optional[bool] = None,
                 mycelium_ip_seed: Optional[str] = None,
                 planetary: Optional[bool] = None,
                 public_ip: Optional[bool] = None,
                 public_ip6: Optional[bool] = None):
        """
        :param int cpu: The cpu units needed for the kubernetes node. Range in [1: 32]
        :param int disk_size: Data disk size in GBs. Must be between 1GB and 10240GBs (10TBs)
        :param int memory: The memory capacity for the kubernetes node in MB. Min is 250 MB
        :param str name: The name of the kubernetes node, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported
        :param str network_name: The name of the network, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported. Network must exist
        :param Any node_id: The node ID to deploy the kubernetes node on, required and should match the requested resources
        :param str description: The description of the kubernetes node, optional with no restrictions
        :param str entry_point: The entry point for the flist. Example: /sbin/zinit init
        :param str flist: The flist to be mounted in the kubernetes node. Example: https://hub.grid.tf/tf-official-apps/base:latest.flist
        :param str flist_checksum: The checksum of the flist which should match the checksum of the given flist, optional
        :param bool mycelium: A flag to generate a random mycelium IP seed to support mycelium in the kubernetes node
        :param str mycelium_ip_seed: The seed used for mycelium IP generated for the kubernetes node. It's length should be 6
        :param bool planetary: A flag to enable generating a yggdrasil IP for the kubernetes node
        :param bool public_ip: A flag to enable generating a public IP for the kubernetes node, public node is required for it
        :param bool public_ip6: A flag to enable generating a public IPv6 for the kubernetes node, public node is required for it
        """
        pulumi.set(__self__, "cpu", cpu)
        pulumi.set(__self__, "disk_size", disk_size)
        pulumi.set(__self__, "memory", memory)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "network_name", network_name)
        pulumi.set(__self__, "node_id", node_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if entry_point is None:
            entry_point = '/sbin/zinit init'
        if entry_point is not None:
            pulumi.set(__self__, "entry_point", entry_point)
        if flist is None:
            flist = 'https://hub.grid.tf/tf-official-apps/threefolddev-k3s-v1.31.0.flist'
        if flist is not None:
            pulumi.set(__self__, "flist", flist)
        if flist_checksum is not None:
            pulumi.set(__self__, "flist_checksum", flist_checksum)
        if mycelium is not None:
            pulumi.set(__self__, "mycelium", mycelium)
        if mycelium_ip_seed is not None:
            pulumi.set(__self__, "mycelium_ip_seed", mycelium_ip_seed)
        if planetary is not None:
            pulumi.set(__self__, "planetary", planetary)
        if public_ip is not None:
            pulumi.set(__self__, "public_ip", public_ip)
        if public_ip6 is not None:
            pulumi.set(__self__, "public_ip6", public_ip6)

    @property
    @pulumi.getter
    def cpu(self) -> int:
        """
        The cpu units needed for the kubernetes node. Range in [1: 32]
        """
        return pulumi.get(self, "cpu")

    @property
    @pulumi.getter
    def disk_size(self) -> int:
        """
        Data disk size in GBs. Must be between 1GB and 10240GBs (10TBs)
        """
        return pulumi.get(self, "disk_size")

    @property
    @pulumi.getter
    def memory(self) -> int:
        """
        The memory capacity for the kubernetes node in MB. Min is 250 MB
        """
        return pulumi.get(self, "memory")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the kubernetes node, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def network_name(self) -> str:
        """
        The name of the network, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported. Network must exist
        """
        return pulumi.get(self, "network_name")

    @property
    @pulumi.getter
    def node_id(self) -> Any:
        """
        The node ID to deploy the kubernetes node on, required and should match the requested resources
        """
        return pulumi.get(self, "node_id")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        The description of the kubernetes node, optional with no restrictions
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def entry_point(self) -> Optional[str]:
        """
        The entry point for the flist. Example: /sbin/zinit init
        """
        return pulumi.get(self, "entry_point")

    @property
    @pulumi.getter
    def flist(self) -> Optional[str]:
        """
        The flist to be mounted in the kubernetes node. Example: https://hub.grid.tf/tf-official-apps/base:latest.flist
        """
        return pulumi.get(self, "flist")

    @property
    @pulumi.getter
    def flist_checksum(self) -> Optional[str]:
        """
        The checksum of the flist which should match the checksum of the given flist, optional
        """
        return pulumi.get(self, "flist_checksum")

    @property
    @pulumi.getter
    def mycelium(self) -> Optional[bool]:
        """
        A flag to generate a random mycelium IP seed to support mycelium in the kubernetes node
        """
        return pulumi.get(self, "mycelium")

    @property
    @pulumi.getter
    def mycelium_ip_seed(self) -> Optional[str]:
        """
        The seed used for mycelium IP generated for the kubernetes node. It's length should be 6
        """
        return pulumi.get(self, "mycelium_ip_seed")

    @property
    @pulumi.getter
    def planetary(self) -> Optional[bool]:
        """
        A flag to enable generating a yggdrasil IP for the kubernetes node
        """
        return pulumi.get(self, "planetary")

    @property
    @pulumi.getter
    def public_ip(self) -> Optional[bool]:
        """
        A flag to enable generating a public IP for the kubernetes node, public node is required for it
        """
        return pulumi.get(self, "public_ip")

    @property
    @pulumi.getter
    def public_ip6(self) -> Optional[bool]:
        """
        A flag to enable generating a public IPv6 for the kubernetes node, public node is required for it
        """
        return pulumi.get(self, "public_ip6")


@pulumi.output_type
class Metadata(dict):
    def __init__(__self__, *,
                 encryption_key: str,
                 prefix: str,
                 backends: Optional[Sequence['outputs.Backend']] = None,
                 encryption_algorithm: Optional[str] = None,
                 type: Optional[str] = None):
        """
        :param str encryption_key: 64 long hex encoded encryption key (e.g. 0000000000000000000000000000000000000000000000000000000000000000)
        :param str prefix: Data stored on the remote metadata is prefixed with
        :param Sequence['Backend'] backends: List of ZDB backends configurations
        :param str encryption_algorithm: configuration to use for the encryption stage. Currently only AES is supported
        :param str type: configuration for the metadata store to use, currently only ZDB is supported
        """
        pulumi.set(__self__, "encryption_key", encryption_key)
        pulumi.set(__self__, "prefix", prefix)
        if backends is not None:
            pulumi.set(__self__, "backends", backends)
        if encryption_algorithm is not None:
            pulumi.set(__self__, "encryption_algorithm", encryption_algorithm)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def encryption_key(self) -> str:
        """
        64 long hex encoded encryption key (e.g. 0000000000000000000000000000000000000000000000000000000000000000)
        """
        return pulumi.get(self, "encryption_key")

    @property
    @pulumi.getter
    def prefix(self) -> str:
        """
        Data stored on the remote metadata is prefixed with
        """
        return pulumi.get(self, "prefix")

    @property
    @pulumi.getter
    def backends(self) -> Optional[Sequence['outputs.Backend']]:
        """
        List of ZDB backends configurations
        """
        return pulumi.get(self, "backends")

    @property
    @pulumi.getter
    def encryption_algorithm(self) -> Optional[str]:
        """
        configuration to use for the encryption stage. Currently only AES is supported
        """
        return pulumi.get(self, "encryption_algorithm")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        """
        configuration for the metadata store to use, currently only ZDB is supported
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class Mount(dict):
    def __init__(__self__, *,
                 mount_point: str,
                 name: str):
        """
        :param str mount_point: The mount point of the disk/volume
        :param str name: The name of the mounted disk/volume, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported
        """
        pulumi.set(__self__, "mount_point", mount_point)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def mount_point(self) -> str:
        """
        The mount point of the disk/volume
        """
        return pulumi.get(self, "mount_point")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the mounted disk/volume, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class QSFSComputed(dict):
    def __init__(__self__, *,
                 metrics_endpoint: str):
        """
        :param str metrics_endpoint: Exposed metrics endpoint
        """
        pulumi.set(__self__, "metrics_endpoint", metrics_endpoint)

    @property
    @pulumi.getter
    def metrics_endpoint(self) -> str:
        """
        Exposed metrics endpoint
        """
        return pulumi.get(self, "metrics_endpoint")


@pulumi.output_type
class QSFSInput(dict):
    def __init__(__self__, *,
                 cache: int,
                 encryption_key: str,
                 expected_shards: int,
                 groups: Sequence['outputs.Group'],
                 max_zdb_data_dir_size: int,
                 metadata: 'outputs.Metadata',
                 minimal_shards: int,
                 name: str,
                 redundant_groups: int,
                 redundant_nodes: int,
                 compression_algorithm: Optional[str] = None,
                 description: Optional[str] = None,
                 encryption_algorithm: Optional[str] = None):
        """
        :param int cache: The size of the fuse mountpoint on the node in MBs (holds qsfs local data before pushing)
        :param str encryption_key: 64 long hex encoded encryption key (e.g. 0000000000000000000000000000000000000000000000000000000000000000)
        :param int expected_shards: The amount of shards which are generated when the data is encoded. Essentially, this is the amount of shards which is needed to be able to recover the data, and some disposable shards which could be lost. The amount of disposable shards can be calculated as expected_shards - minimal_shards
        :param Sequence['Group'] groups: The backend groups to write the data to
        :param int max_zdb_data_dir_size: Maximum size of the data dir in MiB, if this is set and the sum of the file sizes in the data dir gets higher than this value, the least used, already encoded file will be removed
        :param 'Metadata' metadata: List of ZDB backends configurations
        :param int minimal_shards: The minimum amount of shards which are needed to recover the original data
        :param str name: The name of the qsfs workload, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported
        :param int redundant_groups: The amount of groups which one should be able to loose while still being able to recover the original data
        :param int redundant_nodes: The amount of nodes that can be lost in every group while still being able to recover the original data
        :param str compression_algorithm: configuration to use for the compression stage. Currently only snappy is supported
        :param str description: The description of the qsfs workload, optional with no restrictions
        :param str encryption_algorithm: configuration to use for the encryption stage. Currently only AES is supported
        """
        pulumi.set(__self__, "cache", cache)
        pulumi.set(__self__, "encryption_key", encryption_key)
        pulumi.set(__self__, "expected_shards", expected_shards)
        pulumi.set(__self__, "groups", groups)
        pulumi.set(__self__, "max_zdb_data_dir_size", max_zdb_data_dir_size)
        pulumi.set(__self__, "metadata", metadata)
        pulumi.set(__self__, "minimal_shards", minimal_shards)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "redundant_groups", redundant_groups)
        pulumi.set(__self__, "redundant_nodes", redundant_nodes)
        if compression_algorithm is not None:
            pulumi.set(__self__, "compression_algorithm", compression_algorithm)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if encryption_algorithm is not None:
            pulumi.set(__self__, "encryption_algorithm", encryption_algorithm)

    @property
    @pulumi.getter
    def cache(self) -> int:
        """
        The size of the fuse mountpoint on the node in MBs (holds qsfs local data before pushing)
        """
        return pulumi.get(self, "cache")

    @property
    @pulumi.getter
    def encryption_key(self) -> str:
        """
        64 long hex encoded encryption key (e.g. 0000000000000000000000000000000000000000000000000000000000000000)
        """
        return pulumi.get(self, "encryption_key")

    @property
    @pulumi.getter
    def expected_shards(self) -> int:
        """
        The amount of shards which are generated when the data is encoded. Essentially, this is the amount of shards which is needed to be able to recover the data, and some disposable shards which could be lost. The amount of disposable shards can be calculated as expected_shards - minimal_shards
        """
        return pulumi.get(self, "expected_shards")

    @property
    @pulumi.getter
    def groups(self) -> Sequence['outputs.Group']:
        """
        The backend groups to write the data to
        """
        return pulumi.get(self, "groups")

    @property
    @pulumi.getter
    def max_zdb_data_dir_size(self) -> int:
        """
        Maximum size of the data dir in MiB, if this is set and the sum of the file sizes in the data dir gets higher than this value, the least used, already encoded file will be removed
        """
        return pulumi.get(self, "max_zdb_data_dir_size")

    @property
    @pulumi.getter
    def metadata(self) -> 'outputs.Metadata':
        """
        List of ZDB backends configurations
        """
        return pulumi.get(self, "metadata")

    @property
    @pulumi.getter
    def minimal_shards(self) -> int:
        """
        The minimum amount of shards which are needed to recover the original data
        """
        return pulumi.get(self, "minimal_shards")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the qsfs workload, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def redundant_groups(self) -> int:
        """
        The amount of groups which one should be able to loose while still being able to recover the original data
        """
        return pulumi.get(self, "redundant_groups")

    @property
    @pulumi.getter
    def redundant_nodes(self) -> int:
        """
        The amount of nodes that can be lost in every group while still being able to recover the original data
        """
        return pulumi.get(self, "redundant_nodes")

    @property
    @pulumi.getter
    def compression_algorithm(self) -> Optional[str]:
        """
        configuration to use for the compression stage. Currently only snappy is supported
        """
        return pulumi.get(self, "compression_algorithm")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        The description of the qsfs workload, optional with no restrictions
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def encryption_algorithm(self) -> Optional[str]:
        """
        configuration to use for the encryption stage. Currently only AES is supported
        """
        return pulumi.get(self, "encryption_algorithm")


@pulumi.output_type
class VMComputed(dict):
    def __init__(__self__, *,
                 computed_ip: str,
                 computed_ip6: str,
                 console_url: str,
                 mycelium_ip: str,
                 mycelium_ip_seed: str,
                 planetary_ip: str,
                 ip: Optional[str] = None):
        """
        :param str computed_ip: The reserved public ipv4 if any
        :param str computed_ip6: The reserved public ipv6 if any
        :param str console_url: The url to access the vm via cloud console on private interface using wireguard
        :param str mycelium_ip: The allocated mycelium IP
        :param str mycelium_ip_seed: The seed used for mycelium IP generated for the virtual machine. It's length should be 6
        :param str planetary_ip: The allocated Yggdrasil IP
        :param str ip: The private wireguard IP of the vm
        """
        pulumi.set(__self__, "computed_ip", computed_ip)
        pulumi.set(__self__, "computed_ip6", computed_ip6)
        pulumi.set(__self__, "console_url", console_url)
        pulumi.set(__self__, "mycelium_ip", mycelium_ip)
        pulumi.set(__self__, "mycelium_ip_seed", mycelium_ip_seed)
        pulumi.set(__self__, "planetary_ip", planetary_ip)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)

    @property
    @pulumi.getter
    def computed_ip(self) -> str:
        """
        The reserved public ipv4 if any
        """
        return pulumi.get(self, "computed_ip")

    @property
    @pulumi.getter
    def computed_ip6(self) -> str:
        """
        The reserved public ipv6 if any
        """
        return pulumi.get(self, "computed_ip6")

    @property
    @pulumi.getter
    def console_url(self) -> str:
        """
        The url to access the vm via cloud console on private interface using wireguard
        """
        return pulumi.get(self, "console_url")

    @property
    @pulumi.getter
    def mycelium_ip(self) -> str:
        """
        The allocated mycelium IP
        """
        return pulumi.get(self, "mycelium_ip")

    @property
    @pulumi.getter
    def mycelium_ip_seed(self) -> str:
        """
        The seed used for mycelium IP generated for the virtual machine. It's length should be 6
        """
        return pulumi.get(self, "mycelium_ip_seed")

    @property
    @pulumi.getter
    def planetary_ip(self) -> str:
        """
        The allocated Yggdrasil IP
        """
        return pulumi.get(self, "planetary_ip")

    @property
    @pulumi.getter
    def ip(self) -> Optional[str]:
        """
        The private wireguard IP of the vm
        """
        return pulumi.get(self, "ip")


@pulumi.output_type
class VMInput(dict):
    def __init__(__self__, *,
                 cpu: int,
                 flist: str,
                 memory: int,
                 name: str,
                 network_name: str,
                 node_id: Any,
                 description: Optional[str] = None,
                 entrypoint: Optional[str] = None,
                 env_vars: Optional[Mapping[str, str]] = None,
                 flist_checksum: Optional[str] = None,
                 gpus: Optional[Sequence[str]] = None,
                 mounts: Optional[Sequence['outputs.Mount']] = None,
                 mycelium: Optional[bool] = None,
                 mycelium_ip_seed: Optional[str] = None,
                 planetary: Optional[bool] = None,
                 public_ip: Optional[bool] = None,
                 public_ip6: Optional[bool] = None,
                 rootfs_size: Optional[int] = None,
                 zlogs: Optional[Sequence['outputs.Zlog']] = None):
        """
        :param int cpu: The cpu units needed for the virtual machine. Range in [1: 32]
        :param str flist: The flist to be mounted in the virtual machine, required and should be valid. Example: https://hub.grid.tf/tf-official-apps/base:latest.flist
        :param int memory: The memory capacity for the virtual machine in MB. Min is 250 MB
        :param str name: The name of the virtual machine workload, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported
        :param str network_name: The name of the network, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported. Network must exist
        :param Any node_id: The node ID to deploy the virtual machine on, required and should match the requested resources
        :param str description: The description of the virtual machine workload, optional with no restrictions
        :param str entrypoint: The entry point for the flist. Example: /sbin/zinit init
        :param Mapping[str, str] env_vars: The environment variables to be passed to the virtual machine. Example: SSH_KEY
        :param str flist_checksum: The checksum of the flist which should match the checksum of the given flist, optional
        :param Sequence[str] gpus: A list of gpu IDs to be used in the virtual machine. GPU ID format: <slot>/<vendor>/<device>. Example: 0000:28:00.0/1002/731f
        :param Sequence['Mount'] mounts: A list of mounted disks or volumes
        :param bool mycelium: A flag to generate a random mycelium IP seed to support mycelium in the virtual machine
        :param str mycelium_ip_seed: The seed used for mycelium IP generated for the virtual machine. It's length should be 6
        :param bool planetary: A flag to enable generating a yggdrasil IP for the virtual machine
        :param bool public_ip: A flag to enable generating a public IP for the virtual machine, public node is required for it
        :param bool public_ip6: A flag to enable generating a public IPv6 for the virtual machine, public node is required for it
        :param int rootfs_size: The root fs size in GB (type SSD). Can be set as 0 to get the default minimum
        :param Sequence['Zlog'] zlogs: A list of virtual machine loggers
        """
        pulumi.set(__self__, "cpu", cpu)
        pulumi.set(__self__, "flist", flist)
        pulumi.set(__self__, "memory", memory)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "network_name", network_name)
        pulumi.set(__self__, "node_id", node_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if entrypoint is not None:
            pulumi.set(__self__, "entrypoint", entrypoint)
        if env_vars is not None:
            pulumi.set(__self__, "env_vars", env_vars)
        if flist_checksum is not None:
            pulumi.set(__self__, "flist_checksum", flist_checksum)
        if gpus is not None:
            pulumi.set(__self__, "gpus", gpus)
        if mounts is not None:
            pulumi.set(__self__, "mounts", mounts)
        if mycelium is not None:
            pulumi.set(__self__, "mycelium", mycelium)
        if mycelium_ip_seed is not None:
            pulumi.set(__self__, "mycelium_ip_seed", mycelium_ip_seed)
        if planetary is not None:
            pulumi.set(__self__, "planetary", planetary)
        if public_ip is not None:
            pulumi.set(__self__, "public_ip", public_ip)
        if public_ip6 is not None:
            pulumi.set(__self__, "public_ip6", public_ip6)
        if rootfs_size is not None:
            pulumi.set(__self__, "rootfs_size", rootfs_size)
        if zlogs is not None:
            pulumi.set(__self__, "zlogs", zlogs)

    @property
    @pulumi.getter
    def cpu(self) -> int:
        """
        The cpu units needed for the virtual machine. Range in [1: 32]
        """
        return pulumi.get(self, "cpu")

    @property
    @pulumi.getter
    def flist(self) -> str:
        """
        The flist to be mounted in the virtual machine, required and should be valid. Example: https://hub.grid.tf/tf-official-apps/base:latest.flist
        """
        return pulumi.get(self, "flist")

    @property
    @pulumi.getter
    def memory(self) -> int:
        """
        The memory capacity for the virtual machine in MB. Min is 250 MB
        """
        return pulumi.get(self, "memory")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the virtual machine workload, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def network_name(self) -> str:
        """
        The name of the network, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported. Network must exist
        """
        return pulumi.get(self, "network_name")

    @property
    @pulumi.getter
    def node_id(self) -> Any:
        """
        The node ID to deploy the virtual machine on, required and should match the requested resources
        """
        return pulumi.get(self, "node_id")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        The description of the virtual machine workload, optional with no restrictions
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def entrypoint(self) -> Optional[str]:
        """
        The entry point for the flist. Example: /sbin/zinit init
        """
        return pulumi.get(self, "entrypoint")

    @property
    @pulumi.getter
    def env_vars(self) -> Optional[Mapping[str, str]]:
        """
        The environment variables to be passed to the virtual machine. Example: SSH_KEY
        """
        return pulumi.get(self, "env_vars")

    @property
    @pulumi.getter
    def flist_checksum(self) -> Optional[str]:
        """
        The checksum of the flist which should match the checksum of the given flist, optional
        """
        return pulumi.get(self, "flist_checksum")

    @property
    @pulumi.getter
    def gpus(self) -> Optional[Sequence[str]]:
        """
        A list of gpu IDs to be used in the virtual machine. GPU ID format: <slot>/<vendor>/<device>. Example: 0000:28:00.0/1002/731f
        """
        return pulumi.get(self, "gpus")

    @property
    @pulumi.getter
    def mounts(self) -> Optional[Sequence['outputs.Mount']]:
        """
        A list of mounted disks or volumes
        """
        return pulumi.get(self, "mounts")

    @property
    @pulumi.getter
    def mycelium(self) -> Optional[bool]:
        """
        A flag to generate a random mycelium IP seed to support mycelium in the virtual machine
        """
        return pulumi.get(self, "mycelium")

    @property
    @pulumi.getter
    def mycelium_ip_seed(self) -> Optional[str]:
        """
        The seed used for mycelium IP generated for the virtual machine. It's length should be 6
        """
        return pulumi.get(self, "mycelium_ip_seed")

    @property
    @pulumi.getter
    def planetary(self) -> Optional[bool]:
        """
        A flag to enable generating a yggdrasil IP for the virtual machine
        """
        return pulumi.get(self, "planetary")

    @property
    @pulumi.getter
    def public_ip(self) -> Optional[bool]:
        """
        A flag to enable generating a public IP for the virtual machine, public node is required for it
        """
        return pulumi.get(self, "public_ip")

    @property
    @pulumi.getter
    def public_ip6(self) -> Optional[bool]:
        """
        A flag to enable generating a public IPv6 for the virtual machine, public node is required for it
        """
        return pulumi.get(self, "public_ip6")

    @property
    @pulumi.getter
    def rootfs_size(self) -> Optional[int]:
        """
        The root fs size in GB (type SSD). Can be set as 0 to get the default minimum
        """
        return pulumi.get(self, "rootfs_size")

    @property
    @pulumi.getter
    def zlogs(self) -> Optional[Sequence['outputs.Zlog']]:
        """
        A list of virtual machine loggers
        """
        return pulumi.get(self, "zlogs")


@pulumi.output_type
class ZDBComputed(dict):
    def __init__(__self__, *,
                 ips: Sequence[str],
                 namespace: str,
                 port: int):
        """
        :param Sequence[str] ips: Computed IPs of the ZDB. Two IPs are returned: a public IPv6, and a YggIP, in this order
        :param str namespace: Namespace of the ZDB
        :param int port: Port of the ZDB
        """
        pulumi.set(__self__, "ips", ips)
        pulumi.set(__self__, "namespace", namespace)
        pulumi.set(__self__, "port", port)

    @property
    @pulumi.getter
    def ips(self) -> Sequence[str]:
        """
        Computed IPs of the ZDB. Two IPs are returned: a public IPv6, and a YggIP, in this order
        """
        return pulumi.get(self, "ips")

    @property
    @pulumi.getter
    def namespace(self) -> str:
        """
        Namespace of the ZDB
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter
    def port(self) -> int:
        """
        Port of the ZDB
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class ZDBInput(dict):
    def __init__(__self__, *,
                 name: str,
                 password: str,
                 size: int,
                 description: Optional[str] = None,
                 mode: Optional[str] = None,
                 public: Optional[bool] = None):
        """
        :param str name: The name of the 0-db workload, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported
        :param str password: The 0-db password
        :param int size: The 0-db size in GB (type HDD)
        :param str description: The description of the 0-db workload, optional with no restrictions
        :param str mode: the enumeration of the modes 0-db can operate in (default user)
        :param bool public: A flag to make 0-db namespace public - readable by anyone
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "size", size)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if mode is None:
            mode = (_utilities.get_env('') or 'user')
        if mode is not None:
            pulumi.set(__self__, "mode", mode)
        if public is not None:
            pulumi.set(__self__, "public", public)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the 0-db workload, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def password(self) -> str:
        """
        The 0-db password
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def size(self) -> int:
        """
        The 0-db size in GB (type HDD)
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        The description of the 0-db workload, optional with no restrictions
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def mode(self) -> Optional[str]:
        """
        the enumeration of the modes 0-db can operate in (default user)
        """
        return pulumi.get(self, "mode")

    @property
    @pulumi.getter
    def public(self) -> Optional[bool]:
        """
        A flag to make 0-db namespace public - readable by anyone
        """
        return pulumi.get(self, "public")


@pulumi.output_type
class Zlog(dict):
    def __init__(__self__, *,
                 output: str,
                 zmachine: str):
        """
        :param str output: The output logs URL, should be a valid url
        :param str zmachine: The name of virtual machine, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported
        """
        pulumi.set(__self__, "output", output)
        pulumi.set(__self__, "zmachine", zmachine)

    @property
    @pulumi.getter
    def output(self) -> str:
        """
        The output logs URL, should be a valid url
        """
        return pulumi.get(self, "output")

    @property
    @pulumi.getter
    def zmachine(self) -> str:
        """
        The name of virtual machine, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported
        """
        return pulumi.get(self, "zmachine")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .deployment import *
from .gateway_fqdn import *
from .gateway_name import *
from .kubernetes import *
from .network import *
from .provider import *
from .scheduler import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_threefold.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_threefold.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "threefold",
  "mod": "index",
  "fqn": "pulumi_threefold",
  "classes": {
   "threefold:index:Deployment": "Deployment",
   "threefold:index:GatewayFQDN": "GatewayFQDN",
   "threefold:index:GatewayName": "GatewayName",
   "threefold:index:Kubernetes": "Kubernetes",
   "threefold:index:Network": "Network",
   "threefold:index:Scheduler": "Scheduler"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "threefold",
  "token": "pulumi:providers:threefold",
  "fqn": "pulumi_threefold",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['KubernetesArgs', 'Kubernetes']

@pulumi.input_type
class KubernetesArgs:
    def __init__(__self__, *,
                 master: pulumi.Input['K8sNodeInputArgs'],
                 network_name: pulumi.Input[str],
                 token: pulumi.Input[str],
                 workers: pulumi.Input[Sequence[pulumi.Input['K8sNodeInputArgs']]],
                 entry_point: Optional[pulumi.Input[str]] = None,
                 flist: Optional[pulumi.Input[str]] = None,
                 flist_checksum: Optional[pulumi.Input[str]] = None,
                 solution_type: Optional[pulumi.Input[str]] = None,
                 ssh_key: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Kubernetes resource.
        :param pulumi.Input['K8sNodeInputArgs'] master: Master holds the configuration of master node in the kubernetes cluster
        :param pulumi.Input[str] network_name: The name of the network, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported. Network must exist
        :param pulumi.Input[str] token: The cluster secret token. Each node has to have this token to be part of the cluster. This token should be an alphanumeric non-empty string
        :param pulumi.Input[Sequence[pulumi.Input['K8sNodeInputArgs']]] workers: Workers is a list holding the workers configuration for the kubernetes cluster
        :param pulumi.Input[str] entry_point: The entry point for the flist. Example: /sbin/zinit init
        :param pulumi.Input[str] flist: The flist to be mounted in the kubernetes cluster nodes. Example: https://hub.grid.tf/tf-official-apps/base:latest.flist
        :param pulumi.Input[str] flist_checksum: The checksum of the flist which should match the checksum of the given flist, optional
        :param pulumi.Input[str] solution_type: The solution type of the cluster, displayed as project name in contract metadata
        :param pulumi.Input[str] ssh_key: SSH key to access the cluster nodes
        """
        pulumi.set(__self__, "master", master)
        pulumi.set(__self__, "network_name", network_name)
        pulumi.set(__self__, "token", token)
        pulumi.set(__self__, "workers", workers)
        if entry_point is not None:
            pulumi.set(__self__, "entry_point", entry_point)
        if flist is not None:
            pulumi.set(__self__, "flist", flist)
        if flist_checksum is not None:
            pulumi.set(__self__, "flist_checksum", flist_checksum)
        if solution_type is None:
            solution_type = 'kubernetes/'
        if solution_type is not None:
            pulumi.set(__self__, "solution_type", solution_type)
        if ssh_key is None:
            ssh_key = ''
        if ssh_key is not None:
            pulumi.set(__self__, "ssh_key", ssh_key)

    @property
    @pulumi.getter
    def master(self) -> pulumi.Input['K8sNodeInputArgs']:
        """
        Master holds the configuration of master node in the kubernetes cluster
        """
        return pulumi.get(self, "master")

    @master.setter
    def master(self, value: pulumi.Input['K8sNodeInputArgs']):
        pulumi.set(self, "master", value)

    @property
    @pulumi.getter
    def network_name(self) -> pulumi.Input[str]:
        """
        The name of the network, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported. Network must exist
        """
        return pulumi.get(self, "network_name")

    @network_name.setter
    def network_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "network_name", value)

    @property
    @pulumi.getter
    def token(self) -> pulumi.Input[str]:
        """
        The cluster secret token. Each node has to have this token to be part of the cluster. This token should be an alphanumeric non-empty string
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: pulumi.Input[str]):
        pulumi.set(self, "token", value)

    @property
    @pulumi.getter
    def workers(self) -> pulumi.Input[Sequence[pulumi.Input['K8sNodeInputArgs']]]:
        """
        Workers is a list holding the workers configuration for the kubernetes cluster
        """
        return pulumi.get(self, "workers")

    @workers.setter
    def workers(self, value: pulumi.Input[Sequence[pulumi.Input['K8sNodeInputArgs']]]):
        pulumi.set(self, "workers", value)

    @property
    @pulumi.getter
    def entry_point(self) -> Optional[pulumi.Input[str]]:
        """
        The entry point for the flist. Example: /sbin/zinit init
        """
        return pulumi.get(self, "entry_point")

    @entry_point.setter
    def entry_point(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "entry_point", value)

    @property
    @pulumi.getter
    def flist(self) -> Optional[pulumi.Input[str]]:
        """
        The flist to be mounted in the kubernetes cluster nodes. Example: https://hub.grid.tf/tf-official-apps/base:latest.flist
        """
        return pulumi.get(self, "flist")

    @flist.setter
    def flist(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "flist", value)

    @property
    @pulumi.getter
    def flist_checksum(self) -> Optional[pulumi.Input[str]]:
        """
        The checksum of the flist which should match the checksum of the given flist, optional
        """
        return pulumi.get(self, "flist_checksum")

    @flist_checksum.setter
    def flist_checksum(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "flist_checksum", value)

    @property
    @pulumi.getter
    def solution_type(self) -> Optional[pulumi.Input[str]]:
        """
        The solution type of the cluster, displayed as project name in contract metadata
        """
        return pulumi.get(self, "solution_type")

    @solution_type.setter
    def solution_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "solution_type", value)

    @property
    @pulumi.getter
    def ssh_key(self) -> Optional[pulumi.Input[str]]:
        """
        SSH key to access the cluster nodes
        """
        return pulumi.get(self, "ssh_key")

    @ssh_key.setter
    def ssh_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ssh_key", value)


class Kubernetes(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 entry_point: Optional[pulumi.Input[str]] = None,
                 flist: Optional[pulumi.Input[str]] = None,
                 flist_checksum: Optional[pulumi.Input[str]] = None,
                 master: Optional[pulumi.Input[pulumi.InputType['K8sNodeInputArgs']]] = None,
                 network_name: Optional[pulumi.Input[str]] = None,
                 solution_type: Optional[pulumi.Input[str]] = None,
                 ssh_key: Optional[pulumi.Input[str]] = None,
                 token: Optional[pulumi.Input[str]] = None,
                 workers: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['K8sNodeInputArgs']]]]] = None,
                 __props__=None):
        """
        Create a Kubernetes resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] entry_point: The entry point for the flist. Example: /sbin/zinit init
        :param pulumi.Input[str] flist: The flist to be mounted in the kubernetes cluster nodes. Example: https://hub.grid.tf/tf-official-apps/base:latest.flist
        :param pulumi.Input[str] flist_checksum: The checksum of the flist which should match the checksum of the given flist, optional
        :param pulumi.Input[pulumi.InputType['K8sNodeInputArgs']] master: Master holds the configuration of master node in the kubernetes cluster
        :param pulumi.Input[str] network_name: The name of the network, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported. Network must exist
        :param pulumi.Input[str] solution_type: The solution type of the cluster, displayed as project name in contract metadata
        :param pulumi.Input[str] ssh_key: SSH key to access the cluster nodes
        :param pulumi.Input[str] token: The cluster secret token. Each node has to have this token to be part of the cluster. This token should be an alphanumeric non-empty string
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['K8sNodeInputArgs']]]] workers: Workers is a list holding the workers configuration for the kubernetes cluster
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: KubernetesArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a Kubernetes resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param KubernetesArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KubernetesArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 entry_point: Optional[pulumi.Input[str]] = None,
                 flist: Optional[pulumi.Input[str]] = None,
                 flist_checksum: Optional[pulumi.Input[str]] = None,
                 master: Optional[pulumi.Input[pulumi.InputType['K8sNodeInputArgs']]] = None,
                 network_name: Optional[pulumi.Input[str]] = None,
                 solution_type: Optional[pulumi.Input[str]] = None,
                 ssh_key: Optional[pulumi.Input[str]] = None,
                 token: Optional[pulumi.Input[str]] = None,
                 workers: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['K8sNodeInputArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KubernetesArgs.__new__(KubernetesArgs)

            __props__.__dict__["entry_point"] = entry_point
            __props__.__dict__["flist"] = flist
            __props__.__dict__["flist_checksum"] = flist_checksum
            if master is None and not opts.urn:
                raise TypeError("Missing required property 'master'")
            __props__.__dict__["master"] = master
            if network_name is None and not opts.urn:
                raise TypeError("Missing required property 'network_name'")
            __props__.__dict__["network_name"] = network_name
            if solution_type is None:
                solution_type = 'kubernetes/'
            __props__.__dict__["solution_type"] = solution_type
            if ssh_key is None:
                ssh_key = ''
            __props__.__dict__["ssh_key"] = ssh_key
            if token is None and not opts.urn:
                raise TypeError("Missing required property 'token'")
            __props__.__dict__["token"] = token
            if workers is None and not opts.urn:
                raise TypeError("Missing required property 'workers'")
            __props__.__dict__["workers"] = workers
            __props__.__dict__["master_computed"] = None
            __props__.__dict__["node_deployment_id"] = None
            __props__.__dict__["nodes_ip_range"] = None
            __props__.__dict__["workers_computed"] = None
        super(Kubernetes, __self__).__init__(
            'threefold:index:Kubernetes',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None) -> 'Kubernetes':
        """
        Get an existing Kubernetes resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = KubernetesArgs.__new__(KubernetesArgs)

        __props__.__dict__["entry_point"] = None
        __props__.__dict__["flist"] = None
        __props__.__dict__["flist_checksum"] = None
        __props__.__dict__["master"] = None
        __props__.__dict__["master_computed"] = None
        __props__.__dict__["network_name"] = None
        __props__.__dict__["node_deployment_id"] = None
        __props__.__dict__["nodes_ip_range"] = None
        __props__.__dict__["solution_type"] = None
        __props__.__dict__["ssh_key"] = None
        __props__.__dict__["token"] = None
        __props__.__dict__["workers"] = None
        __props__.__dict__["workers_computed"] = None
        return Kubernetes(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def entry_point(self) -> pulumi.Output[Optional[str]]:
        """
        The entry point for the flist. Example: /sbin/zinit init
        """
        return pulumi.get(self, "entry_point")

    @property
    @pulumi.getter
    def flist(self) -> pulumi.Output[Optional[str]]:
        """
        The flist to be mounted in the kubernetes cluster nodes. Example: https://hub.grid.tf/tf-official-apps/base:latest.flist
        """
        return pulumi.get(self, "flist")

    @property
    @pulumi.getter
    def flist_checksum(self) -> pulumi.Output[Optional[str]]:
        """
        The checksum of the flist which should match the checksum of the given flist, optional
        """
        return pulumi.get(self, "flist_checksum")

    @property
    @pulumi.getter
    def master(self) -> pulumi.Output['outputs.K8sNodeInput']:
        """
        Master holds the configuration of master node in the kubernetes cluster
        """
        return pulumi.get(self, "master")

    @property
    @pulumi.getter
    def master_computed(self) -> pulumi.Output['outputs.VMComputed']:
        """
        The computed fields of the master node
        """
        return pulumi.get(self, "master_computed")

    @property
    @pulumi.getter
    def network_name(self) -> pulumi.Output[str]:
        """
        The name of the network, it's required and cannot exceed 50 characters. Only alphanumeric and underscores characters are supported. Network must exist
        """
        return pulumi.get(self, "network_name")

    @property
    @pulumi.getter
    def node_deployment_id(self) -> pulumi.Output[Mapping[str, int]]:
        """
        Mapping from each node to its deployment ID
        """
        return pulumi.get(self, "node_deployment_id")

    @property
    @pulumi.getter
    def nodes_ip_range(self) -> pulumi.Output[Mapping[str, str]]:
        """
        Computed values of nodes' IP ranges after deployment
        """
        return pulumi.get(self, "nodes_ip_range")

    @property
    @pulumi.getter
    def solution_type(self) -> pulumi.Output[Optional[str]]:
        """
        The solution type of the cluster, displayed as project name in contract metadata
        """
        return pulumi.get(self, "solution_type")

    @property
    @pulumi.getter
    def ssh_key(self) -> pulumi.Output[Optional[str]]:
        """
        SSH key to access the cluster nodes
        """
        return pulumi.get(self, "ssh_key")

    @property
    @pulumi.getter
    def token(self) -> pulumi.Output[str]:
        """
        The cluster secret token. Each node has to have this token to be part of the cluster. This token should be an alphanumeric non-empty string
        """
        return pulumi.get(self, "token")

    @property
    @pulumi.getter
    def workers(self) -> pulumi.Output[Sequence['outputs.K8sNodeInput']]:
        """
        Workers is a list holding the workers configuration for the kubernetes cluster
        """
        return pulumi.get(self, "workers")

    @property
    @pulumi.getter
    def workers_computed(self) -> pulumi.Output[Mapping[str, 'outputs.VMComputed']]:
        """
        List of the computed fields of the worker nodes
        """
        return pulumi.get(self, "workers_computed")

